pub enum Error {
OLEError(Error),
NotThumbsDbFile,
IOError(Error),
NotJPEGFile,
NoEntryAssociated,
}Expand description
Errors related to the process of parsing and reading.
Variants
OLEError(Error)
This happens if an error occured with OLE.
NotThumbsDbFile
This happens if the given file isn’t a Thumbs.db file.
IOError(Error)
Classic std::io::Error.
NotJPEGFile
This happens if a thumbnail isn’t a JPEG file.
NoEntryAssociated
This happens if a thumbnail is declared inside the Catalog entry, but The entry doesn’t actually exist inside the Thumbs.db.